You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by sg...@apache.org on 2008/07/18 22:40:45 UTC

svn commit: r678029 - in /commons/proper/exec/trunk/src/main/java/org/apache/commons/exec: CommandLine.java util/StringUtils.java

Author: sgoeschl
Date: Fri Jul 18 13:40:44 2008
New Revision: 678029

URL: http://svn.apache.org/viewvc?rev=678029&view=rev
Log:
[EXEC-25] Fixed typo in method name

Modified:
    commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/CommandLine.java
    commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/util/StringUtils.java

Modified: commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/CommandLine.java
URL: http://svn.apache.org/viewvc/commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/CommandLine.java?rev=678029&r1=678028&r2=678029&view=diff
==============================================================================
--- commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/CommandLine.java (original)
+++ commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/CommandLine.java Fri Jul 18 13:40:44 2008
@@ -122,7 +122,7 @@
         // Expand the executable and replace '/' and '\\' with the platform
         // specific file seperator char. This is safe here since we know
         // that this is a platform specific command.
-        return StringUtils.fixFileSeperatorChar(expandArgument(executable));
+        return StringUtils.fixFileSeparatorChar(expandArgument(executable));
     }
 
     /** @return Was a file being used to set the executable? */
@@ -408,7 +408,7 @@
         } else if(executable.trim().length() == 0) {
             throw new IllegalArgumentException("Executable can not be empty");
         } else {
-            this.executable = StringUtils.fixFileSeperatorChar(executable);        
+            this.executable = StringUtils.fixFileSeparatorChar(executable);
         }
     }
 }

Modified: commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/util/StringUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/util/StringUtils.java?rev=678029&r1=678028&r2=678029&view=diff
==============================================================================
--- commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/util/StringUtils.java (original)
+++ commons/proper/exec/trunk/src/main/java/org/apache/commons/exec/util/StringUtils.java Fri Jul 18 13:40:44 2008
@@ -159,7 +159,7 @@
      * @param arg the argument to fix
      * @return the transformed argument 
      */
-    public static String fixFileSeperatorChar(String arg) {
+    public static String fixFileSeparatorChar(String arg) {
         return arg.replace(SLASH_CHAR, File.separatorChar).replace(
                 BACKSLASH_CHAR, File.separatorChar);
     }
@@ -168,14 +168,14 @@
      * Concatenates an array of string using a seperator.
      *
      * @param strings the strings to concatenate
      * @param seperator the seperator between two strings
      * @return the concatened strings
      */
-    public static String toString(String[] strings, String seperator) {    
+    public static String toString(String[] strings, String separator) {
         StringBuffer sb = new StringBuffer();
         for (int i = 0; i < strings.length; i++) {
             if (i > 0) {
-                sb.append(seperator);
+                sb.append(separator);
             }
             sb.append(strings[i]);
         }
@@ -168,14 +168,14 @@
      *
      * @param strings the strings to concatenate
-     * @param seperator the seperator between two strings
+     * @param separator the seperator between two strings
      * @return the concatened strings
      */